@@ -6,7 +6,7 @@ Kafka::Internals - Constants and functions used internally.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::Internals> version 0.9011 .
+This documentation refers to C<Kafka::Internals> version 0.9012 .
 
 =cut
 
@@ -18,7 +18,7 @@ use warnings;
 
 # ENVIRONMENT ------------------------------------------------------------------
 
-our $VERSION = '0.9011';
+our $VERSION = '0.9012';
 
 use Exporter qw(
     import
@@ -248,7 +248,7 @@ sub format_reference {
             ->Quotekeys( 0 )
             ->Sortkeys( 1 )
             ->Useperl( 1 )      # XS version seems to have a bug which sometimes results in modification of original object
-            ->Sparseseen( 1 )   # speed up since we don't use "Seen" hash
+#            ->Sparseseen( 1 )   # speed up since we don't use "Seen" hash
         ;
     }
 
